def father():
    print("my father is biju")
def mother():
    print("my mther is anitha")
def sister():
    print("my sister is chandralekha")
def pet():
    print("my pet is monkuttan")
def housename():
    print("sivasailam")
def plcae():
    print("keralapuram, kollam, kerala")
def personalno():
    print("8089156390")